@@ -208,7 +208,7 @@ class ApplicationProperties:
         property_name: str,
         property_type: type,
         default_value: Any = None,
-        valid_value_fn: Optional[Callable[[Any], None]] = None,
+        valid_value_fn: Optional[Callable[[Any], Any]] = None,
         is_required: bool = False,
         strict_mode: Optional[Any] = None,
     ) -> Any:
@@ -291,7 +291,7 @@ class ApplicationProperties:
         self,
         property_name: str,
         default_value: Optional[int] = None,
-        valid_value_fn: Optional[Callable[[int], None]] = None,
+        valid_value_fn: Optional[Callable[[int], Any]] = None,
         is_required: bool = False,
         strict_mode: Optional[bool] = None,
     ) -> int:
@@ -317,7 +317,7 @@ class ApplicationProperties:
         self,
         property_name: str,
         default_value: Optional[str] = None,
-        valid_value_fn: Optional[Callable[[str], None]] = None,
+        valid_value_fn: Optional[Callable[[str], Any]] = None,
         is_required: bool = False,
         strict_mode: Optional[bool] = None,
     ) -> str:
