@@ -42,7 +42,7 @@ class ApplicationPropertiesFacade:
         property_name: str,
         property_type: type,
         default_value: Any = None,
-        valid_value_fn: Optional[Callable[[Any], None]] = None,
+        valid_value_fn: Optional[Callable[[Any], Any]] = None,
         is_required: bool = False,
         strict_mode: Optional[Any] = None,
     ) -> Any:
@@ -81,7 +81,7 @@ class ApplicationPropertiesFacade:
         self,
         property_name: str,
         default_value: Optional[int] = None,
-        valid_value_fn: Optional[Callable[[int], None]] = None,
+        valid_value_fn: Optional[Callable[[int], Any]] = None,
         is_required: bool = False,
         strict_mode: Optional[bool] = None,
     ) -> int:
@@ -103,7 +103,7 @@ class ApplicationPropertiesFacade:
         self,
         property_name: str,
         default_value: Optional[str] = None,
-        valid_value_fn: Optional[Callable[[str], None]] = None,
+        valid_value_fn: Optional[Callable[[str], Any]] = None,
         is_required: bool = False,
         strict_mode: Optional[bool] = None,
     ) -> str:
